Client

Enum Client 

pub enum Client {
    Http(HttpClient),
    Ws(WsReconnectClient<WsClient>),
}
Available on non-WebAssembly only.
Json RPC client.

Variants



Http(HttpClient)

A client using ‘http[s]’ protocol.



Ws(WsReconnectClient<WsClient>)

A client using ‘ws[s]’ protocol.

Implementations

Source

impl Client

pub async fn new( url: &str, auth_token: Option<&str>, connect_timeout: Option<Duration>, request_timeout: Option<Duration>, ) -> Result<Self, Error>

Create a new Json RPC client.

Only ‘http[s]’ and ‘ws[s]’ protocols are supported and they should be specified in the provided url. For more flexibility consider creating the client using jsonrpsee directly.

Please note that currently the celestia-node supports only ‘http’ and ‘ws’. For a secure connection you have to hide it behind a proxy.