pub struct TxConfig {
pub signer_address: Option<AccAddress>,
pub key_name: Option<String>,
pub gas_price: Option<f64>,
pub max_gas_price: Option<f64>,
pub gas: Option<u64>,
pub priority: Option<TxPriority>,
pub fee_granter_address: Option<AccAddress>,
}Expand description
TxConfig specifies additional options that are be applied to the Tx.
If no options are provided, then the default ones will be used.
Read more about the mechanisms of fees and gas usage in submitting data blobs.
Fields
signer_address: Option<AccAddress>Specifies the address from the keystore that will sign transactions.
NOTE
Only signer_address or key_name should be passed. signer_address is a primary cfg.
This means If both the address and the key are specified, the address field will take priority.
key_name: Option<String>Specifies the key from the keystore associated with an account that will be used to sign transactions.
NOTE
This account must be available in the Keystore.
gas_price: Option<f64>Represents the amount to be paid per gas unit.
Negative or missing gas_price means user want us to use the minGasPrice defined in the node.
max_gas_price: Option<f64>Represents the maximal amount to be paid per gas unit.
gas: Option<u64>Calculated amount of gas to be used by transaction.
0 or missing gas means that the node should calculate it itself.
priority: Option<TxPriority>Transaction priority level used when estimating the gas price.
fee_granter_address: Option<AccAddress>Specifies the account that will pay for the transaction.
Implementations
Sourceimpl TxConfig
impl TxConfig
Sourcepub fn with_gas_price(self, gas_price: f64) -> Self
pub fn with_gas_price(self, gas_price: f64) -> Self
Sets the gas_price of the transaction.
Sourcepub fn with_max_gas_price(self, max_gas_price: f64) -> Self
pub fn with_max_gas_price(self, max_gas_price: f64) -> Self
Sets the max_gas_price of the transaction.
Sourcepub fn with_priority(self, priority: TxPriority) -> Self
pub fn with_priority(self, priority: TxPriority) -> Self
Sets the priority of the transaction.
Sourcepub fn with_fee_granter_address(self, fee_granter_address: AccAddress) -> Self
pub fn with_fee_granter_address(self, fee_granter_address: AccAddress) -> Self
Sets the fee_granter_address of the transaction.
Sourcepub fn with_signer_address(self, signer_address: AccAddress) -> Self
pub fn with_signer_address(self, signer_address: AccAddress) -> Self
Sets the signer_address of the transaction.
Sourcepub fn with_key_name(self, key_name: impl Into<String>) -> Self
pub fn with_key_name(self, key_name: impl Into<String>) -> Self
Sets the key_name of the transaction.